#!/bin/bash
#  This script is part of Numdiff
#  Copyright (C)  2005-2007    Ivano Primi  <ivprimi@libero.it>    
#
#   Copying and distribution of this file, with or without modification,
#   are permitted in any medium without royalty provided the copyright
#   notice and this notice are preserved.

LESS="less"
DIFF="diff"
#DIFF=/home/ivano/myprojs/numdiff/tests/Numdiff
NUMDIFF="numdiff"
#NUMDIFF="/home/ivano/myprojs/numdiff/numdiff"

echo "Viewer: $LESS"
echo "Tester program: $DIFF"
echo "Numdiff: $NUMDIFF"

TESTS="test1 test2 test3 test4 test5 test6 test7 test8 test9"

for TEST in $TESTS
do
  if [ $TEST == "test1" ]; then
      cd $TEST
  else
      cd ../$TEST
  fi
  echo -e "\nCurrent working directory: $PWD"
  RUNTEST="./run$TEST.sh"
  $RUNTEST $LESS $DIFF $NUMDIFF
done

